@@ -47,7 +47,7 @@ sub __parseArgv
 			version => 0,
 			execmap => undef,			# no execmap from file to apply
 			define => {},				# arbitrary key=value defines
-			include => undef,			# no filter (select all tests)
+			skip => undef,				# no skip filter
 			jobs => 1,					# run only one job at a time (no parallelism)
 			timer => 0,					# don't show timing output
 			workdirectory => undef,		# explicit directory to use
@@ -64,7 +64,7 @@ sub __parseArgv
 			'version',
 			'execmap=s',
 			'define|D=s%',
-			'include=s',
+			'skip=s',
 			'jobs=i',
 			'timer!',
 			'workdirectory=s',
@@ -95,18 +95,26 @@ sub __parseArgv
 	pod2usage(-input => $argsPodInput, -exitval => 0, -verbose => 0) if $rawOpts{usage};
 	pod2usage(-message => "$0 version $version", -exitval => 0, -verbose => 99, -sections => '_') if $rawOpts{version};
 
-	# create the user include filter for pruning the list of tests later
+	# use the user skip filter for pruning the list of tests later
+	# Note however, that since we later want to select *included* files, 
+	# we nefariously reverse the expression given
 	#
 	eval
 	{
-		$self->{include} =
-			defined($rawOpts{include})
-				? Grep::Query->new($rawOpts{include})
-				: undef;
+		if (defined($rawOpts{skip}))
+		{
+			# before we reverse the meaning, try to compile the query first, to trigger any syntax problem now
+			#
+			Grep::Query->new($rawOpts{skip});
+			
+			# still alive, add our reverse
+			#
+			$self->{include} = Grep::Query->new("NOT ( $rawOpts{skip} )");
+		}
 	};
 	if ($@)
 	{
-		pod2usage(-message => "Failure creating include filter:\n  $@", -exitval => 255, -verbose => 0);
+		pod2usage(-message => "Failure creating skip filter:\n  $@", -exitval => 255, -verbose => 0);
 	}
 
 	# make sure we have a valid jobs value
